==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property acms
 * @property files
 * @property sds
 */
public data class GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust(
    public val acms: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustAcm>,
    public val files: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustFile>,
    public val sds: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustSd>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust):
            GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust =
            GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust(
                acms = javaType.acms().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustAcm.Companion.toKotlin(args0)
                    })
                }),
                files = javaType.files().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustFile.Companion.toKotlin(args0)
                    })
                }),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustSd.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property acms
 * @property files
 * @property sds
 */
public data class GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust(
    public val acms: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustAcm>,
    public val files: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustFile>,
    public val sds: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustSd>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust): GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust =
            GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrust(
                acms = javaType.acms().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustAcm.Companion.toKotlin(args0)
                    })
                }),
                files = javaType.files().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustFile.Companion.toKotlin(args0)
                    })
                }),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidationTrustSd.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}
